@@ -40,13 +40,8 @@ warnings.filterwarnings("ignore")
 from tensorflow.python.util import deprecation
 deprecation._PRINT_DEPRECATION_WARNINGS = False
 
-try:
-    f = open('setup.py')
-    for li, l in enumerate(f):
-        if li == 8:
-            EQT_VERSION = l.split('"')[1]
-except Exception:
-    EQT_VERSION = None
+
+EQT_VERSION = "0.1.56"
 
 def predictor(input_dir=None,
               input_model=None,
@@ -242,10 +237,12 @@ def predictor(input_dir=None,
     if os.path.isdir(out_dir):
         print('============================================================================')        
         print(f' *** {out_dir} already exists!')
-        inp = input(" --> Type (Yes or y) to create a new empty directory! otherwise it will overwrite!   ")
+        inp = input(" --> Type (Yes or y) to create a new empty directory! This will remove your previous results!  ")
         if inp.lower() == "yes" or inp.lower() == "y":
             shutil.rmtree(out_dir)  
             os.makedirs(out_dir) 
+        else:
+            return
      
     station_list = [ev.split(".")[0] for ev in listdir(args['input_dir']) if ev.split('/')[-1] != '.DS_Store'];
     station_list = sorted(set(station_list))
